@@ -2,7 +2,7 @@
 
 import json
 
-from understory import term
+from understory import micropub, term
 
 import micropub
 
@@ -30,10 +30,13 @@ class Micropub:
         except KeyError:
             if self.channel:
                 properties["channel"] = self.channel
-        location, links = micropub.client.create_post(
-            properties, endpoint=self.endpoint, h=self.type, token=self.token
-        )
+        client = micropub.client.Client(self.endpoint, self.token)
+        location, links = client.create_post(properties, h=self.type)
         print("Location:", location)
         if links:
             print("Links:", links)
         return 0
+
+
+if __name__ == "__main__":
+    main()
